
# Cocos2d
from cocos.director import director
from cocos.layer import Layer
from cocos.text import Label
from cocos.actions import ScaleBy, Reverse, FadeOut, CallFunc

from shape import Shape
from cell import *
from audio import AudioPlayer

class HUD(Layer):
    is_event_handler = False
    def __init__(self):
        super(HUD,self).__init__()
        
        self.score = int(director.return_value)
        self.scoreDisplay = Label(str(self.score),font_name= "M01_CPS", font_size=10,  color=(255,255,255,255))
        self.scoreDisplay.x = 680
        self.scoreDisplay.y = 500
        self.add(self.scoreDisplay)
 
        self.specials = []
        self.specialsActive = []
        
    def SetLevelInfo(self, title):
        title = Label(title, font_size=10,font_name= "M01_CPS",  color=(255,255,255,255))
        title.x = 511
        title.y = 470
        self.add(title)
        
    def Matched(self, shape, combo):
        self.score += shape.points*combo
        self.scoreDisplay.element.text = "%d" % self.score
        
        if (combo >1):
            AudioPlayer[0].PlaySound("combo.ogg")
            txt = Label("Combo X "+str(combo),font_name= "M01_CPS", font_size = 10)
            txt.x = 0
            txt.y = 300
            txt.do(FadeOut(1))
            txt.do(ScaleBy(5,1)+CallFunc( self.remove, txt ))
            self.add(txt)
            
        if (shape.numberNeeded == 0 and shape.specialActivated != None):
            self.SetSpecialActive(shape.specialActivated, True)
            AudioPlayer[0].PlaySound("special.ogg")

        
        
    def SetSpecialsAvail(self, specials):
        self.specials = [] 
        x = 0
        for special in specials:
            specialObj = MakeCell(special+SPECIALS_OFFSET)
            specialObj.x = 160+x*32 #+x*2
            specialObj.y = 560
            self._SetSpecialActive(specialObj, False)
            
            self.specials.append(specialObj)
            self.specialsActive.append(False)
            
            self.add(specialObj)
            x += 1 
    
    def IsSpecialActive(self, specialIdx):
        return (self.specialsActive[specialIdx], self.specials[specialIdx].cell_ID)
        
    def SetSpecialActive(self, specialIdx, isActive):
        self._SetSpecialActive(self.specials[specialIdx], isActive)
        self.specialsActive[specialIdx] = isActive
        
    def _SetSpecialActive(self, special, isActive):
        if (isActive):
            special.color = (128,255,128)
            special.opacity = 255
        else:
            special.color = (100,100,100)
            special.opacity = 128
            
        seq = ScaleBy( 1.1, 0.2 )
        special.do(seq+ Reverse(seq))
       
        
        
    def on_enter(self):
        super( HUD, self).on_enter()
        
    def on_exit(self):
        super( HUD, self).on_exit()
